@@ -22,12 +22,13 @@ import typing
 
 
 from base64 import b64decode, b64encode
+from collections.abc import Mapping
 from decimal import Decimal
 from solana.blockhash import Blockhash, BlockhashCache
 from solana.keypair import Keypair
 from solana.publickey import PublicKey
 from solana.rpc.api import Client
-from solana.rpc.commitment import Commitment, Processed
+from solana.rpc.commitment import Commitment, Processed, Finalized
 from solana.rpc.providers.http import HTTPProvider
 from solana.rpc.types import DataSliceOpts, MemcmpOpts, RPCMethod, RPCResponse, TokenAccountOpts, TxOpts
 from solana.transaction import Transaction
@@ -35,11 +36,33 @@ from solana.transaction import Transaction
 from .constants import SOL_DECIMAL_DIVISOR
 from .instructionreporter import InstructionReporter
 from .logmessages import expand_log_messages
+from .text import indent_collection_as_str
 
 
 _STUB_TRANSACTION_SIGNATURE: str = "stub-for-already-submitted-transaction-signature"
 
 
+# # 🥭 CompoundException class
+#
+# A `CompoundException` exception can hold all exceptions that were raised when trying to read or
+# write to Solana.
+#
+# The `Client` can rotate through multiple providers, switching when certain `Exception`s are thrown.
+# This exception allows all those exceptions to be gathered and inspected should all providers fail.
+#
+class CompoundException(Exception):
+    def __init__(self, name: str, all_exceptions: typing.Sequence[Exception]) -> None:
+        super().__init__(f"[{name}] Multiple errors captured for event")
+        self.name: str = name
+        self.all_exceptions: typing.Sequence[Exception] = all_exceptions
+
+    def __str__(self) -> str:
+        details: str = indent_collection_as_str(self.all_exceptions)
+        return f"""« CompoundException with {len(self.all_exceptions)} inner exceptions:
+    {details}
+»"""
+
+
 # # 🥭 ClientException class
 #
 # A `ClientException` exception base class that allows trapping and handling rate limiting
@@ -348,7 +371,7 @@ class RPCCaller(HTTPProvider):
         #
         # Only do this check if we're using a commitment level of 'processed'.
         if len(params) > 1 and "commitment" in params[1] and params[1]["commitment"] == Processed:
-            if "result" in response and "context" in response["result"] and "slot" in response["result"]["context"]:
+            if "result" in response and isinstance(response["result"], Mapping) and "context" in response["result"] and isinstance(response["result"]["context"], Mapping) and "slot" in response["result"]["context"]:
                 slot: int = response["result"]["context"]["slot"]
                 self._logger.debug(f"{method}() data is from slot: {slot}")
                 if not self.slot_holder.is_acceptable(slot):
@@ -391,6 +414,9 @@ class RPCCaller(HTTPProvider):
                                            self.cluster_url, method, parameters, response_text, error_accounts,
                                            error_err, error_logs, self.instruction_reporter)
 
+        if method == "getRecentBlockhash":
+            self._logger.debug(f"Recent blockhash fetched: {response}")
+
         # The call succeeded.
         return typing.cast(RPCResponse, response)
 
@@ -407,9 +433,10 @@ class RPCCaller(HTTPProvider):
 # and switch provider on exceptions that show that provider is no longer at the tip of the chain.
 #
 class CompoundRPCCaller(HTTPProvider):
-    def __init__(self, providers: typing.Sequence[RPCCaller]):
+    def __init__(self, name: str, providers: typing.Sequence[RPCCaller]):
         self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.__providers: typing.Sequence[RPCCaller] = providers
+        self.name: str = name
         self.on_provider_change: typing.Callable[[], None] = lambda: None
 
     @property
@@ -435,7 +462,7 @@ class CompoundRPCCaller(HTTPProvider):
         self._logger.debug(f"Told to shift provider - now using: {self.__providers[0]}")
 
     def make_request(self, method: RPCMethod, *params: typing.Any) -> RPCResponse:
-        last_exception: Exception
+        all_exceptions: typing.List[Exception] = []
         for provider in self.__providers:
             try:
                 result = provider.make_request(method, *params)
@@ -446,14 +473,15 @@ class CompoundRPCCaller(HTTPProvider):
                     self.on_provider_change()
                     self._logger.debug(f"Shifted provider - now using: {self.__providers[0]}")
                 return result
-            except (RateLimitException,
+            except (requests.exceptions.HTTPError,
+                    RateLimitException,
                     NodeIsBehindException,
                     StaleSlotException,
                     FailedToFetchBlockhashException) as exception:
-                last_exception = exception
+                all_exceptions += [exception]
                 self._logger.info(f"Moving to next provider - {provider} gave {exception}")
 
-        raise last_exception
+        raise CompoundException(self.name, all_exceptions)
 
     def is_connected(self) -> bool:
         # All we need for this to be true is for one of our providers to be connected.
@@ -511,7 +539,7 @@ class BetterClient:
                                               slot_holder, instruction_reporter)
             rpc_callers += [rpc_caller]
 
-        provider: CompoundRPCCaller = CompoundRPCCaller(rpc_callers)
+        provider: CompoundRPCCaller = CompoundRPCCaller(name, rpc_callers)
         blockhash_cache: typing.Union[BlockhashCache, bool] = False
         if blockhash_cache_duration > 0:
             blockhash_cache = BlockhashCache(blockhash_cache_duration)
@@ -521,8 +549,10 @@ class BetterClient:
         def __on_provider_change() -> None:
             if client.blockhash_cache:
                 # Clear out the blockhash cache on retrying
-                client.blockhash_cache.unused_blockhashes.clear()
-                client.blockhash_cache.used_blockhashes.clear()
+                logging.debug("Replacing client blockhash cache.")
+                client.blockhash_cache = BlockhashCache(blockhash_cache_duration)
+                blockhash_resp = client.get_recent_blockhash(Finalized)
+                client._process_blockhash_resp(blockhash_resp, used_immediately=False)
 
         provider.on_provider_change = __on_provider_change
 
@@ -623,12 +653,14 @@ class BetterClient:
         for provider in self.rpc_caller.all_providers:
             try:
                 proper_commitment: Commitment = opts.preflight_commitment
+                proper_skip_preflight = opts.skip_preflight
                 if proper_commitment == UnspecifiedCommitment:
                     proper_commitment = self.commitment
+                    proper_skip_preflight = self.skip_preflight
 
                 proper_opts = TxOpts(preflight_commitment=proper_commitment,
                                      skip_confirmation=opts.skip_confirmation,
-                                     skip_preflight=opts.skip_preflight)
+                                     skip_preflight=proper_skip_preflight)
 
                 response = self.compatible_client.send_transaction(transaction, *signers, opts=proper_opts)
                 signature: str = str(response["result"])
