@@ -1555,4 +1555,7 @@ InstructionParsersByVariant = {
     43: UNSPECIFIED,  # ADD_PERP_TRIGGER_ORDER,
     44: UNSPECIFIED,  # REMOVE_ADVANCED_ORDER,
     45: UNSPECIFIED,  # EXECUTE_PERP_TRIGGER_ORDER,
+    46: UNSPECIFIED,  # CREATE_PERP_MARKET,
+    47: UNSPECIFIED,  # CHANGE_PERP_MARKET_PARAMS2,
+    48: UNSPECIFIED,  # UPDATE_MARGIN_BASKET,
 }
