@@ -73,7 +73,7 @@ class ConfidenceIntervalElement(Element):
                                                     quantity=position_size, order_type=self.order_type)
             ask_order = mango.Order.from_basic_info(mango.Side.SELL, price=ask,
                                                     quantity=position_size, order_type=self.order_type)
-            self.logger.debug(f"""Desired orders:
+            self._logger.debug(f"""Desired orders:
     Bid: {bid_order}
     Ask: {ask_order}""")
             new_orders += [bid_order, ask_order]
@@ -83,10 +83,10 @@ class ConfidenceIntervalElement(Element):
 
         top_bid = model_state.top_bid
         top_ask = model_state.top_ask
-        self.logger.debug(f"""Initial desired orders - spread {model_state.spread} ({top_bid.price if top_bid else None} / {top_ask.price if top_ask else None}):
+        self._logger.debug(f"""Initial desired orders - spread {model_state.spread} ({top_bid.price if top_bid else None} / {top_ask.price if top_ask else None}):
     {order_text}""")
         return new_orders
 
     def __str__(self) -> str:
         confidence_interval_levels = ", ".join(map(str, self.confidence_interval_levels)) or "None"
-        return f"« 𝙲𝚘𝚗𝚏𝚒𝚍𝚎𝚗𝚌𝚎𝙸𝚗𝚝𝚎𝚛𝚟𝚊𝚕𝙴𝚕𝚎𝚖𝚎𝚗𝚝 {self.order_type} - position size: {self.position_size_ratio}, confidence interval levels: {confidence_interval_levels} »"
+        return f"« ConfidenceIntervalElement {self.order_type} - position size: {self.position_size_ratio}, confidence interval levels: {confidence_interval_levels} »"
