@@ -32,7 +32,7 @@ from ...modelstate import ModelState
 #
 class Element(metaclass=abc.ABCMeta):
     def __init__(self) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
 
     @staticmethod
     def add_command_line_parameters(parser: argparse.ArgumentParser) -> None:
@@ -50,4 +50,4 @@ class Element(metaclass=abc.ABCMeta):
         return f"{self}"
 
     def __str__(self) -> str:
-        return """« 𝙴𝚕𝚎𝚖𝚎𝚗𝚝 »"""
+        return """« Element »"""
