@@ -72,7 +72,7 @@ class MinimumChargeElement(PairwiseElement):
             if current_charge < minimum_charge:
                 new_price = measurement_price - minimum_charge
                 new_buy = buy.with_price(new_price)
-                self.logger.debug(f"""Order change - old BUY price {buy.price:,.8f} distance from {measurement_price:,.8f} would return {current_charge:,.8f} which is less than minimum charge {minimum_charge:,.8f}:
+                self._logger.debug(f"""Order change - old BUY price {buy.price:,.8f} distance from {measurement_price:,.8f} would return {current_charge:,.8f} which is less than minimum charge {minimum_charge:,.8f}:
     Old: {buy}
     New: {new_buy}""")
 
@@ -83,11 +83,11 @@ class MinimumChargeElement(PairwiseElement):
             if current_charge < minimum_charge:
                 new_price = measurement_price + minimum_charge
                 new_sell = sell.with_price(new_price)
-                self.logger.debug(f"""Order change - old SELL price {sell.price:,.8f} distance from {measurement_price:,.8f} would return {current_charge:,.8f} which is less than minimum charge {minimum_charge:,.8f}:
+                self._logger.debug(f"""Order change - old SELL price {sell.price:,.8f} distance from {measurement_price:,.8f} would return {current_charge:,.8f} which is less than minimum charge {minimum_charge:,.8f}:
     Old: {sell}
     New: {new_sell}""")
 
         return new_buy, new_sell
 
     def __str__(self) -> str:
-        return f"« 𝙼𝚒𝚗𝚒𝚖𝚞𝚖𝙲𝚑𝚊𝚛𝚐𝚎𝙴𝚕𝚎𝚖𝚎𝚗𝚝 - minimum charge ratios: {self.minimumcharge_ratios} »"
+        return f"« MinimumChargeElement - minimum charge ratios: {self.minimumcharge_ratios} »"
