@@ -24,7 +24,7 @@ from .version import Version
 #
 class Metadata():
     def __init__(self, data_type: typing.Any, version: Version, is_initialized: bool) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.data_type: typing.Any = data_type
         self.version: Version = version
         self.is_initialized: bool = is_initialized
@@ -36,7 +36,7 @@ class Metadata():
 
     def __str__(self) -> str:
         init = "Initialized" if self.is_initialized else "Not Initialized"
-        return f"« 𝙼𝚎𝚝𝚊𝚍𝚊𝚝𝚊 {self.version} - {self.data_type}: {init} »"
+        return f"« Metadata {self.version} - {self.data_type}: {init} »"
 
     def __repr__(self) -> str:
         return f"{self}"
