@@ -58,7 +58,7 @@ _DEFAULT_WALLET_FILENAME: str = "id.json"
 
 class Wallet:
     def __init__(self, secret_key: bytes) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
         self.secret_key: bytes = secret_key[0:32]
         self.keypair: Keypair = Keypair(self.secret_key)
 
@@ -131,7 +131,7 @@ class Wallet:
         return wallet
 
     def __str__(self) -> str:
-        return f"« 𝚆𝚊𝚕𝚕𝚎𝚝 for {self.address} »"
+        return f"« Wallet for {self.address} »"
 
     def __repr__(self) -> str:
         return f"{self}"
